package edu.lawrence.directoryviews

import retrofit2.Call
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.http.Body
import retrofit2.http.DELETE
import retrofit2.http.GET
import retrofit2.http.POST
import retrofit2.http.Path
import retrofit2.http.Query

interface DirectoryApiService {
    @POST("users")
    fun newUser(@Body user : User) : Call<String>

    @GET("users")
    fun login(@Query("user") user : String, @Query("password") password : String) : Call<String>

    @GET("people/{key}")
    fun getPeople(@Path("key") key : String) : Call<List<Person>>

    @POST("people/{key}")
    fun postPerson(@Path("key") key : String, @Body person : Person) : Call<Person>

    @DELETE("people/{key}/{id}")
    fun removePerson(@Path("key") key : String, @Path("id") id : Int) : Call<String>

    companion object {
        var directoryService: DirectoryApiService? = null

        fun getInstance() : DirectoryApiService {
            if (directoryService == null) {
                val retrofit = Retrofit.Builder()
                    .addConverterFactory(GsonConverterFactory.create())
                    .baseUrl("https://cmsc106.net/directory/")
                    .build()
                directoryService = retrofit.create(DirectoryApiService::class.java)
            }
            return directoryService!!
        }
    }
}