package edu.lawrence.directoryviews

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class DirectoryViewModel : ViewModel() {
    val userId = MutableLiveData<String>()
    val error = MutableLiveData<String>()
    val people = MutableLiveData<List<Person>>()
    val newPerson = MutableLiveData<Person>()

    private val service = DirectoryApiService.getInstance()

    fun newUser(name : String,password : String) {
        val newUser = User(name,password)
        val response = service.newUser(newUser)
        response.enqueue(object : Callback<String> {
            override fun onResponse(call: Call<String>, response: Response<String>) {
                if (response.isSuccessful) {
                    userId.postValue(response.body())
                } else {
                    error.postValue("New user failed")
                }
            }

            override fun onFailure(call: Call<String>, t: Throwable) {
                error.postValue("New user failed")
            }
        })
    }

    fun login(name : String,password : String) {
        val response = service.login(name,password)
        response.enqueue(object : Callback<String> {
            override fun onResponse(call: Call<String>, response: Response<String>) {
                if (response.isSuccessful) {
                    userId.postValue(response.body())
                } else {
                    error.postValue("Login failed")
                }
            }

            override fun onFailure(call: Call<String>, t: Throwable) {
                error.postValue("Login failed")
            }
        })
    }

    fun getPeople(key: String) {
        val response = service.getPeople(key = key)
        response.enqueue(object : Callback<List<Person>> {
            override fun onResponse(call: Call<List<Person>>, response: Response<List<Person>>) {
                if (response.isSuccessful) {
                    people.postValue(response.body())
                } else {
                    error.postValue("Get people failed")
                }
            }

            override fun onFailure(call: Call<List<Person>>, t: Throwable) {
                error.postValue("Get people failed")
            }
        })
    }

    fun addPerson(key: String,person : Person) {
        val response = service.postPerson(key = key,person = person)
        response.enqueue(object : Callback<Person> {
            override fun onResponse(call: Call<Person>, response: Response<Person>) {
                if (response.isSuccessful) {
                    newPerson.postValue(response.body())
                    getPeople(key = key)
                } else {
                    error.postValue("Add person failed")
                }
            }

            override fun onFailure(call: Call<Person>, t: Throwable) {
                error.postValue("Add person failed")
            }
        })
    }

    fun removePerson(key: String,id : Int) {
        val response = service.removePerson(key = key,id = id)

        response.enqueue(object : Callback<String> {
            override fun onResponse(call: Call<String>, response: Response<String>) {
                if (response.isSuccessful) {
                    getPeople(key = key)
                } else {
                    error.postValue("Remove person failed")
                }
            }

            override fun onFailure(call: Call<String>, t: Throwable) {
                error.postValue("Remove person failed")
            }
        })
    }
}