package edu.lawrence.directoryviews

import android.content.Intent
import android.os.Bundle
import android.view.Menu
import android.view.MenuItem
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import androidx.core.view.ViewCompat
import androidx.core.view.WindowInsetsCompat
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView

class ListActivity : AppCompatActivity() {
    var key : String? = null
    private lateinit var peopleList : RecyclerView
    private lateinit var viewModel : DirectoryViewModel
    private var adapter : PersonAdapter? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContentView(R.layout.activity_list)
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.createLayout)) { v, insets ->
            val systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars())
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom)
            insets
        }
        setSupportActionBar(findViewById(R.id.topbar))
        key = intent.getStringExtra("Key")

        peopleList = findViewById(R.id.peopleList)
        peopleList.layoutManager = LinearLayoutManager(this)

        viewModel = ViewModelProvider(this)[DirectoryViewModel::class.java]
        viewModel.people.observe(this, Observer {
            adapter = PersonAdapter(viewModel.people.value!!)
            peopleList.adapter = adapter
        })
        viewModel.getPeople(key!!)
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.directory_menu,menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == R.id.plus_item && key != null) {
            val intent = Intent(this,CreateActivity::class.java)
            intent.putExtra("Key",key!!)
            startActivity(intent)
        }
        return true
    }

    private inner class PersonHolder(view : View) : RecyclerView.ViewHolder(view) {
        val nameTextView : TextView = itemView.findViewById<TextView>(R.id.nameText)
        val officeTextView : TextView = itemView.findViewById<TextView>(R.id.officeText)
    }

    private inner class PersonAdapter(var people: List<Person>)
        : RecyclerView.Adapter<PersonHolder>() {
        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): PersonHolder {
            val view = layoutInflater.inflate(R.layout.list_item_people,parent,false)
            return PersonHolder(view)
        }

        override fun getItemCount(): Int {
            return people.size
        }

        override fun onBindViewHolder(holder: PersonHolder, position: Int) {
            val person = people[position]
            holder.apply {
                nameTextView.text = person.name
                officeTextView.text = person.office
            }
        }
        }
}